==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/id.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Dibagikan dengan Anda",
    "Shared with others" : "Dibagikan dengan lainnya",
    "Shared by link" : "Dibagikan dengan tautan",
    "Nothing shared with you yet" : "Tidak ada yang dibagikan kepada Anda",
    "Files and folders others share with you will show up here" : "Berkas dan folder lainnya yang dibagikan kepada Anda akan ditampilkan disini",
    "Nothing shared yet" : "Tidak ada yang dibagikan",
    "Files and folders you share will show up here" : "Berkas dan folder yang Anda bagikan akan ditampilkan disini",
    "No shared links" : "Tidak ada tautan berbagi",
    "Files and folders you share by link will show up here" : "Berkas dan folder yang Anda bagikan menggunakan tautan akan ditampilkan disini",
    "You can upload into this folder" : "Anda dapat mengunggah kedalam folder ini",
    "No compatible server found at {remote}" : "Tidak ditemukan server yang kompatibel pada {remote}",
    "Invalid server URL" : "Server URL tidak valid",
    "Failed to add the public link to your Nextcloud" : "Gagal menambah tautan publik ke Nextcloud Anda",
    "No expiration date set" : "Tanggal kedaluwarsa tidak diatur",
    "Shared by" : "Dibagikan oleh",
    "Sharing" : "Berbagi",
    "A file or folder has been <strong>shared</strong>" : "Sebuah berkas atau folder telah <strong>dibagikan</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Sebuah berkas atau folder telah dibagikan dari <strong>server lainnya</strong>",
    "You received a new remote share %2$s from %1$s" : "Anda menerima berbagi remote baru %2$s dari %1$s",
    "You received a new remote share from %s" : "Anda menerima berbagi remote baru dari %s",
    "%1$s accepted remote share %2$s" : "%1$s menerima berbagi remote %2$s",
    "%1$s declined remote share %2$s" : "%1$s menolak berbagi remote %2$s",
    "%1$s unshared %2$s from you" : "%1$s menghapus berbagi %2$s dari Anda",
    "Public shared folder %1$s was downloaded" : "Folder berbagi publik %1$s telah diunduh",
    "Public shared file %1$s was downloaded" : "Berkas berbagi publik %1$s telah diunduh",
    "You shared %1$s with %2$s" : "Anda membagikan %1$s dengan %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s berbagi %1$s kepada %3$s",
    "You removed the share of %2$s for %1$s" : "Anda menghapus pembagian %2$s untuk %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s menghapus pembagian %3$s untuk %1$s",
    "You shared %1$s with group %2$s" : "Anda membagikan %1$s dengan grup %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s berbagi %1$s kepada grup %3$s",
    "You removed the share of group %2$s for %1$s" : "Anda menghapus pembagian grup %2$s untuk %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s menghapus pembagian grup %3$s untuk %1$s",
    "%2$s shared %1$s via link" : "%2$s berbagi %1$s via tautan",
    "You shared %1$s via link" : "Anda membagikan %1$s via tautan",
    "You removed the public link for %1$s" : "Anda menghapus tautan publik untuk %1$s",
    "%2$s removed the public link for %1$s" : "%2$s menghapus tautan publik untuk %1$s",
    "Your public link for %1$s expired" : "tautan publik Anda untuk %1$s kedaluwarsa",
    "The public link of %2$s for %1$s expired" : "tautan publik %2$s untuk %1$s kedaluwarsa",
    "%2$s shared %1$s with you" : "%2$s membagikan %1$s dengan Anda",
    "%2$s removed the share for %1$s" : "%2$s menghapus pembagian untuk %1$s",
    "Downloaded via public link" : "Diunduh via tautan publik",
    "Shared with %2$s" : "Dibagikan kepada %2$s",
    "Shared with %3$s by %2$s" : "Dibagikan kepada %3$s oleh %2$s",
    "Removed share for %2$s" : "Menghapus pembagian untuk %2$s",
    "%2$s removed share for %3$s" : "%2$s menghapus pembagian untuk %3$s",
    "Shared with group %2$s" : "Dibagikan kepada grup %2$s",
    "Shared with group %3$s by %2$s" : "Dibagikan kepada grup %3$s oleh %2$s",
    "Removed share of group %2$s" : "Menghapus pembagian untuk grup %2$s",
    "%2$s removed share of group %3$s" : "%2$s menghapus pembagian untuk grup %3$s",
    "Shared via link by %2$s" : "Dibagikan via tautan oleh %2$s",
    "Shared via public link" : "Dibagikan via tautan publik",
    "Removed public link" : "tautan publik dihapus",
    "%2$s removed public link" : "%2$s menghapus tautan publik",
    "Public link expired" : "tautan publik kedaluwarsa",
    "Public link of %2$s expired" : "tautan publik untuk %2$s kedaluwarsa",
    "Shared by %2$s" : "Dibagikan oleh %2$s",
    "Wrong share ID, share doesn't exist" : "ID pembagian salah, tidak ada yang bisa dibagi",
    "could not delete share" : "tidak dapat menghapus pembagian",
    "Could not delete share" : "Tidak dapat menghapus pembagian",
    "Please specify a file or folder path" : "Tentukan berkas atau folder",
    "Wrong path, file/folder doesn't exist" : "Salah path, berkas/folder tidak ada",
    "Could not create share" : "Tidak dapat membuat pembagian",
    "invalid permissions" : "izin tidak sah",
    "Please specify a valid user" : "Tentukan pengguna yang valid",
    "Group sharing is disabled by the administrator" : "Berbagi grup dinonaktifkan oleh administrator",
    "Please specify a valid group" : "Tentukan grup yang valid",
    "Public link sharing is disabled by the administrator" : "Pembagian tautan publik dinonaktifkan oleh administrator",
    "Public upload disabled by the administrator" : "Pengunggahan publik dinonaktifkan oleh administrator",
    "Public upload is only possible for publicly shared folders" : "Pengunggahan publik hanya bisa untuk folder yang dibagikan kepada publik",
    "Invalid date, date format must be YYYY-MM-DD" : "Tanggal salah, format tanggal harus TTTT-BB-HH",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Gagal berbagi %s karena backend tidak mengizinkan berbagi dengan tipe %s",
    "Unknown share type" : "Tipe berbagi tidak diketahui",
    "Not a directory" : "Bukan direktori",
    "Could not lock path" : "Tidak dapat mengunci path",
    "Wrong or no update parameter given" : "Parameter salah atau tidak diperbarui",
    "Can't change permissions for public share links" : "Tidak dapat mengubah izin untuk tautan berbagi publik",
    "Cannot increase permissions" : "Tidak dapat menambah izin",
    "Share API is disabled" : "API pembagian dinonaktifkan",
    "This share is password-protected" : "Berbagi ini dilindungi sandi",
    "The password is wrong. Try again." : "Sandi salah. Coba lagi",
    "Password" : "Sandi",
    "No entries found in this folder" : "Tidak ada entri yang ditemukan dalam folder ini",
    "Name" : "Nama",
    "Share time" : "Waktu berbagi",
    "Expiration date" : "Tanggal kedaluwarsa",
    "Sorry, this link doesn’t seem to work anymore." : "Maaf, tautan ini tampaknya tidak berfungsi lagi.",
    "Reasons might be:" : "Alasan yang mungkin:",
    "the item was removed" : "item telah dihapus",
    "the link expired" : "tautan telah kedaluwarsa",
    "sharing is disabled" : "berbagi dinonaktifkan",
    "For more info, please ask the person who sent this link." : "Untuk info lebih lanjut, silakan tanyakan orang yang mengirim tautan ini.",
    "Add to your Nextcloud" : "Tambahkan ke Nextcloud Anda",
    "Download" : "Unduh",
    "Download %s" : "Unduh %s",
    "Direct link" : "Tautan langsung",
    "Upload files to %s" : "Unggah berkas ke %s",
    "Select or drop files" : "Pilih atau drop berkas",
    "Uploading files…" : "Mengunggah berkas...",
    "Uploaded files:" : "Berkas terunggah:",
    "A public shared file or folder was <strong>downloaded</strong>" : "Sebuah berkas atau folder berbagi publik telah <strong>diunduh</strong>",
    "Shares" : "Dibagikan",
    "Server to server sharing is not enabled on this server" : "Berbagi server ke server tidak diaktifkan pada server ini",
    "The mountpoint name contains invalid characters." : "Nama mount point berisi karakter yang tidak sah.",
    "Not allowed to create a federated share with the same user server" : "Tidak diizinkan membuat pembagian terfederasi dengan server pengguna yang sama",
    "Invalid or untrusted SSL certificate" : "Sertifikat SSL tidak sah atau tidak terpercaya",
    "Could not authenticate to remote share, password might be wrong" : "Tidak dapat mengautentikasi berbagi remote, kata sandi mungkin salah",
    "Storage not valid" : "Penyimpanan tidak sah",
    "Couldn't add remote share" : "Tidak dapat menambahkan berbagi remote",
    "Federated sharing" : "Pembagian terfederasi",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Apakah Anda ingin menambahkan berbagi remote {name} dari {owner}@{remote}?",
    "Remote share" : "Berbagi remote",
    "Remote share password" : "Sandi berbagi remote",
    "Cancel" : "Batalkan",
    "Add remote share" : "Tambah berbagi remote",
    "No ownCloud installation (7 or higher) found at {remote}" : "Tidak ditemukan instalasi ownCloud (7 atau lebih tinggi) pada {remote}",
    "Invalid ownCloud url" : "URL ownCloud tidak sah",
    "You received \"/%2$s\" as a remote share from %1$s" : "Anda menerima \"/%2$s\" sebagai berbagi remote dari %1$s",
    "Accept" : "Terima",
    "Decline" : "Tolak",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Bagikan pada saya melalui #ownCloud Federated Cloud ID saya, lihat %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Bagikan pada saya melalui #ownCloud Federated Cloud ID saya",
    "Federated Cloud Sharing" : "Pembagian Awan Terfederasi",
    "Open documentation" : "Buka dokumentasi",
    "Allow users on this server to send shares to other servers" : "Izinkan para pengguna di server ini untuk mengirimkan berbagi ke server lainnya.",
    "Allow users on this server to receive shares from other servers" : "Izinkan para pengguna di server ini untuk menerima berbagi ke server lainnya.",
    "Federated Cloud" : "Awan Terfederasi",
    "Your Federated Cloud ID:" : "ID Awan Terfederasi Anda:",
    "Share it:" : "Bagikan:",
    "Add to your website" : "Tambahkan pada situs web Anda",
    "Share with me via Nextcloud" : "Bagikan pada saya via Nextcloud",
    "HTML Code:" : "Kode HTML:"
},
"nplurals=1; plural=0;");

==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/id.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Dibagikan dengan Anda",
    "Shared with others" : "Dibagikan dengan lainnya",
    "Shared by link" : "Dibagikan dengan tautan",
    "Nothing shared with you yet" : "Tidak ada yang dibagikan kepada Anda",
    "Files and folders others share with you will show up here" : "Berkas dan folder lainnya yang dibagikan kepada Anda akan ditampilkan disini",
    "Nothing shared yet" : "Tidak ada yang dibagikan",
    "Files and folders you share will show up here" : "Berkas dan folder yang Anda bagikan akan ditampilkan disini",
    "No shared links" : "Tidak ada tautan berbagi",
    "Files and folders you share by link will show up here" : "Berkas dan folder yang Anda bagikan menggunakan tautan akan ditampilkan disini",
    "You can upload into this folder" : "Anda dapat mengunggah kedalam folder ini",
    "No compatible server found at {remote}" : "Tidak ditemukan server yang kompatibel pada {remote}",
    "Invalid server URL" : "Server URL tidak valid",
    "Failed to add the public link to your Nextcloud" : "Gagal menambah tautan publik ke Nextcloud Anda",
    "No expiration date set" : "Tanggal kedaluwarsa tidak diatur",
    "Shared by" : "Dibagikan oleh",
    "Sharing" : "Berbagi",
    "Downloaded via public link" : "Diunduh via tautan publik",
    "Removed public link" : "tautan publik dihapus",
    "Public link expired" : "tautan publik kedaluwarsa",
    "A file or folder was shared from <strong>another server</strong>" : "Sebuah berkas atau folder telah dibagikan dari <strong>server lainnya</strong>",
    "A file or folder has been <strong>shared</strong>" : "Sebuah berkas atau folder telah <strong>dibagikan</strong>",
    "Wrong share ID, share doesn't exist" : "ID pembagian salah, tidak ada yang bisa dibagi",
    "could not delete share" : "tidak dapat menghapus pembagian",
    "Could not delete share" : "Tidak dapat menghapus pembagian",
    "Please specify a file or folder path" : "Tentukan berkas atau folder",
    "Wrong path, file/folder doesn't exist" : "Salah path, berkas/folder tidak ada",
    "Could not create share" : "Tidak dapat membuat pembagian",
    "invalid permissions" : "izin tidak sah",
    "Please specify a valid user" : "Tentukan pengguna yang valid",
    "Group sharing is disabled by the administrator" : "Berbagi grup dinonaktifkan oleh administrator",
    "Please specify a valid group" : "Tentukan grup yang valid",
    "Public link sharing is disabled by the administrator" : "Pembagian tautan publik dinonaktifkan oleh administrator",
    "Public upload disabled by the administrator" : "Pengunggahan publik dinonaktifkan oleh administrator",
    "Public upload is only possible for publicly shared folders" : "Pengunggahan publik hanya bisa untuk folder yang dibagikan kepada publik",
    "Invalid date, date format must be YYYY-MM-DD" : "Tanggal salah, format tanggal harus TTTT-BB-HH",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Gagal berbagi %s karena backend tidak mengizinkan berbagi dengan tipe %s",
    "Unknown share type" : "Tipe berbagi tidak diketahui",
    "Not a directory" : "Bukan direktori",
    "Could not lock path" : "Tidak dapat mengunci path",
    "Wrong or no update parameter given" : "Parameter salah atau tidak diperbarui",
    "Can't change permissions for public share links" : "Tidak dapat mengubah izin untuk tautan berbagi publik",
    "Cannot increase permissions" : "Tidak dapat menambah izin",
    "Download" : "Unduh",
    "Direct link" : "Tautan langsung",
    "Add to your Nextcloud" : "Tambahkan ke Nextcloud Anda",
    "Share API is disabled" : "API pembagian dinonaktifkan",
    "This share is password-protected" : "Berbagi ini dilindungi kata sandi",
    "The password is wrong. Try again." : "Kata sandi salah. Coba lagi",
    "Password" : "Kata sandi",
    "No entries found in this folder" : "Tidak ada entri yang ditemukan dalam folder ini",
    "Name" : "Nama",
    "Share time" : "Waktu berbagi",
    "Expiration date" : "Tanggal kedaluwarsa",
    "Sorry, this link doesn’t seem to work anymore." : "Maaf, tautan ini tampaknya tidak berfungsi lagi.",
    "Reasons might be:" : "Alasan yang mungkin:",
    "the item was removed" : "item telah dihapus",
    "the link expired" : "tautan telah kedaluwarsa",
    "sharing is disabled" : "berbagi dinonaktifkan",
    "For more info, please ask the person who sent this link." : "Untuk info lebih lanjut, silakan tanyakan orang yang mengirim tautan ini.",
    "Download %s" : "Unduh %s",
    "Upload files to %s" : "Unggah berkas ke %s",
    "Select or drop files" : "Pilih atau drop berkas",
    "Uploading files…" : "Mengunggah berkas...",
    "Uploaded files:" : "Berkas terunggah:"
},
"nplurals=1; plural=0;");
